# Contributing to aieng-bot

Thanks for your interest in contributing to the aieng-bot!

To submit PRs, please fill out the PR template along with the PR. If the PR
fixes an issue, don't forget to link the PR to the issue!
